Struct std::storage::storage_vec::StorageVec
pub struct StorageVec<V> {}Expand description
A storage type for storing a vector of elements of type V.
StorageVec can contain storage types and can be contained
in storage types. E.g.:
StorageVec<StorageVec<u64>>StorageVec<StorageMap<u64, b256>>StorageMap<u64, StorageVec<b256>>
Some StorageVec methods are not supported for
nested storage types and will revert if used with nested
storage types. E.g., StorageVec<StorageString>::remove
will revert.
**Some StorageVec methods can have limitations and exceptional
behaviors when used with nested storage types.
E.g., StorageVec<StorageString>::pop will pop the last element,
but it will always return None and the StorageString will not
be removed from the storage.
To see if some StorageVec method is supported for nested storage types
at all, or if it has any limitations or exceptional behavior,
refer to method documentation.